@@ -236,7 +236,7 @@ Spec sexp2spec(SEXP lspec) {
 
 bool isSpec(SEXP s) {
    SEXP cls;
-   if (OBJECT(s)) {
+   if (Rf_isObject(s)) {
      cls = Rf_getAttrib(s, R_ClassSymbol);
      for (int i = 0; i < LENGTH(cls); i++)
        if (!strcmp(CHAR(STRING_ELT(cls, i)), "unnest.spec"))
